package weatherService;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.net.URLConnection;

/** this service should return the current weather at the given location */
public class WeatherService {

  /**
   * Get the weather at the given location
   *
   * @param location
   *          the location
   * @return the weather record
   */
  public Weather getWeather(final Location location) {
    final Weather weather;
    weather = new Weather();
    try {
      WeatherService.getWebsite(location);

      // TODO: fill in your code here

    } catch (final Throwable error) {
      /** ignore */
    } finally {
      return weather;
    }
  }

  /**
   * Open the website as input stream.
   *
   * @param location
   *          the location
   * @return the query
   * @throws IOException
   *           if I/O fails
   */
  private static final String getWebsite(final Location location)
      throws IOException {
    // this method downloads the website into a String
    URL url;
    String urlString;
    String string;
    int trials;
    URLConnection con;

    for (trials = 1; trials <= 10; trials++) {
      for (final String start : new String[] { "http", "https" }) {
        try {
          urlString = (start + "://www.timeanddate.com/weather/");

          urlString += location.getCountry().toLowerCase();

          string = location.getCity();
          if (string != null) {
            urlString += '/' + string.toLowerCase();
          }

          url = new URL(urlString);
          con = url.openConnection();
          con.setConnectTimeout(1000 * trials);
          con.setDoOutput(false);
          con.setAllowUserInteraction(false);
          con.setDefaultUseCaches(false);
          con.setDoInput(true);
          con.setReadTimeout(1000 * trials);
          con.setUseCaches(false);
          con.connect();

          return WeatherService.__load(con.getInputStream());
        } catch (final Throwable failure) {
          failure.printStackTrace();
        }
      }
    }

    throw new IllegalStateException(
        "No connection to Yahoo Weather possible.");
  }

  /**
   * Load an input stream into a string
   *
   * @param is
   *          the input stream
   * @return the string
   * @throws IOException
   *           if something goes wrong
   */
  private final static String __load(final InputStream is)
      throws IOException {
    final StringBuilder sb;
    String string;

    sb = new StringBuilder();
    try (final InputStreamReader isr = new InputStreamReader(is)) {
      try (final BufferedReader br = new BufferedReader(isr)) {
        while ((string = br.readLine()) != null) {
          sb.append(string);
        }
      }
    }
    return sb.toString();
  }

  public static final void main(final String[] args) throws IOException {
    final Location l = new Location();
    l.setCountry("china");
    l.setProvince("anhui");
    l.setCity("hefei");
    System.out.print(WeatherService.getWebsite(l));
  }
}
